@@ -12,167 +12,6 @@
 #' \dontrun{
 #'    GSDataStoreManager$new("http://localhost:8080/geoserver", "admin", "geoserver")
 #'  }
-#'
-#' @section Constructor:
-#' \describe{
-#'  \item{\code{new(url, user, pwd, logger)}}{
-#'    This method is used to instantiate a GSManager with the \code{url} of the
-#'    GeoServer and credentials to authenticate (\code{user}/\code{pwd}). By default,
-#'    the \code{logger} argument will be set to \code{NULL} (no logger). This argument
-#'    accepts two possible values: \code{INFO}: to print only geosapi logs,
-#'    \code{DEBUG}: to print geosapi and CURL logs
-#'  }
-#' }
-#' 
-#' @section \code{DataStore} methods:
-#' \describe{ 
-#'  \item{\code{getDataStores(ws)}}{
-#'    Get the list of available dataStores. Returns an object of class \code{list}
-#'    giving items of class \code{\link{GSDataStore}}
-#'  }
-#'  \item{\code{getDataStoreNames(ws)}}{
-#'    Get the list of available dataStore names. Returns an vector of class \code{character}
-#'  }
-#'  \item{\code{getDataStore(ws, ds)}}{
-#'    Get an object of class \code{\link{GSDataStore}} given a workspace and datastore
-#'    names.
-#'  }
-#'  \item{\code{createDataStore(ws, dataStore)}}{
-#'    Creates a new datastore given a workspace and an object of class \code{\link{GSDataStore}}
-#'  }
-#'  \item{\code{updateDataStore(ws, dataStore)}}{
-#'    Updates an existing dataStore given a workspace and an object of class \code{\link{GSDataStore}}
-#'  }
-#'  \item{\code{deleteDataStore(ws, ds, recurse)}}{
-#'    Deletes a datastore given a workspace and an object of class \code{\link{GSDataStore}}.
-#'    By defaut, the option \code{recurse} is set to FALSE, ie datastore layers are not removed.
-#'    To remove all datastore layers, set this option to TRUE.
-#'  }
-#' }
-#' 
-#' @section \code{FeatureType} methods:
-#' \describe{ 
-#'  \item{\code{getFeatureTypes(ws, ds)}}{
-#'    Get the list of available feature types for given workspace and datastore.
-#'    Returns an object of class \code{list} giving items of class \code{\link{GSFeatureType}}
-#'  }
-#'  \item{\code{getFeatureTypeNames(ws, ds)}}{
-#'    Get the list of available feature type names for given workspace and datastore.
-#'    Returns an vector of class\code{character}
-#'  }
-#'  \item{\code{getFeatureType(ws, ds, ft)}}{
-#'    Get an object of class \code{\link{GSFeatureType}} given a workspace, datastore
-#'    and feature type names.
-#'  }
-#'  \item{\code{createFeatureType(ws, ds, featureType)}}{
-#'    Creates a new featureType given a workspace, datastore names and an object of
-#'    class \code{\link{GSFeatureType}}
-#'  }
-#'  \item{\code{updateFeatureType(ws, ds, FeatureType)}}{
-#'    Updates a featureType given a workspace, datastore names and an object of
-#'    class \code{\link{GSFeatureType}}
-#'  }
-#'  \item{\code{deleteFeatureType(ws, ds, featureType, recurse)}}{
-#'    Deletes a featureType given a workspace, datastore names, and an object of 
-#'    class \code{\link{GSFeatureType}}. By defaut, the option \code{recurse} is 
-#'    set to FALSE, ie datastore layers are not removed.
-#'  }
-#' }
-#' 
-#' @section \code{Layer} methods:
-#' \describe{ 
-#'  \item{\code{getLayers()}}{
-#'    Get the list of layers. Returns an object of class \code{list} giving items 
-#'    of class \code{\link{GSLayer}}
-#'  }
-#'  \item{\code{getLayerNames()}}{
-#'    Get the list of layer names.
-#'  }
-#'  \item{\code{getLayer(lyr)}}{
-#'    Get an object of class \code{\link{GSLayer}} if existing
-#'  }
-#'  \item{\code{createLayer(layer)}}{
-#'    Creates a new layer given an object of class \code{\link{GSLayer}}
-#'  }
-#'  \item{\code{updateLayer(layer)}}{
-#'    Creates a layer given an object of class \code{\link{GSLayer}}
-#'  }
-#'  \item{\code{deleteLayer(layer)}}{
-#'    Deletes a layer given an object of class \code{\link{GSLayer}}
-#'  }
-#' }
-#' 
-#' @section \code{LayerGroup} methods:
-#' \describe{ 
-#'  \item{\code{getLayerGroups()}}{
-#'    Get the list of layers. Returns an object of class \code{list} giving items 
-#'    of class \code{\link{GSLayer}}
-#'  }
-#'  \item{\code{getLayerGroupNames()}}{
-#'    Get the list of layer names.
-#'  }
-#'  \item{\code{getLayerGroup(lyr, ws)}}{
-#'    Get an object of class \code{\link{GSLayerGroup}} if existing. Can be restrained
-#'    to a workspace.
-#'  }
-#'  \item{\code{createLayerGroup(layerGroup, ws)}}{
-#'    Creates a new layer given an object of class \code{\link{GSLayerGroup}}. Can be
-#'    restrained to a particular workspace.
-#'  }
-#'  \item{\code{updateLayerGroup(layerGroup, ws)}}{
-#'    Creates a layer given an object of class \code{\link{GSLayerGroup}}. Can be
-#'    restrained to a particular workspace.
-#'  }
-#'  \item{\code{deleteLayerGroup(layerGroup, ws)}}{
-#'    Deletes a layer given an object of class \code{\link{GSLayerGroup}}. Can be
-#'    restrained to a particular workspace.
-#'  }
-#' }
-#' 
-#' @section Main \code{Layer} user publication methods:
-#' \describe{ 
-#'  \item{\code{publishLayer(ws, ds, featureType, layer)}}{
-#'    Publish a web-layer (including the featureType and 'layer' resources), given
-#'    a workspace, a datastore, providing an object of class \code{GSFeatureType},
-#'    and \code{GSLayer}
-#'  }
-#'  \item{\code{unpublishLayer(ws, ds, lyr)}}{
-#'    Unpublish a web-layer (including the featureType and 'layer' resources), given
-#'    a workspace, a datastore, and a layer name
-#'  }
-#' }
-#' 
-#' @section Data upload methods:
-#' \describe{ 
-#'  \item{\code{uploadData(ws, ds, endpoint, extension,
-#'                         configure, update, filename, charset, contentType)}}{
-#'    Uploads data to a target dataStore
-#'  }
-#'  \item{\code{uploadShapefile(ws, ds, endpoint,
-#'                              configure, update, filename, charset)}}{
-#'    Uploads a zipped ESRIshapefile to a target dataStore
-#'  }
-#'  \item{\code{uploadProperties(ws, ds, endpoint,
-#'                               configure, update, filename, charset)}}{
-#'    Uploads a properties file to a target dataStore
-#'  }
-#'  \item{\code{uploadH2(ws, ds, endpoint,
-#'                       configure, update, filename, charset)}}{
-#'    Uploads a H2 database to a target dataStore
-#'  }
-#'  \item{\code{uploadSpatialite(ws, ds, endpoint,
-#'                               configure, update, filename, charset)}}{
-#'    Uploads a Spatialite database to a target dataStore
-#'  }
-#'  \item{\code{uploadAppschema(ws, ds, endpoint,
-#'                               configure, update, filename, charset)}}{
-#'    Uploads a appschema file to a target dataStore
-#'  }
-#'  \item{\code{uploadGeopackage(ws, ds, endpoint,
-#'                               configure, update, filename, charset)}}{
-#'    Uploads a GeoPackage file to a target dataStore                             
-#'  }
-#' }
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -184,8 +23,9 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
     #DataStore generic CRUD methods
     #===========================================================================
     
-    #getDataStores
-    #---------------------------------------------------------------------------
+    #'@description Get the list of available dataStores. 
+    #'@param ws workspace name
+    #'@return an object of class \code{list} giving items of class \code{\link{GSAbstractDataStore}}
     getDataStores = function(ws){
       self$INFO(sprintf("Fetching list of datastores in workspace '%s'", ws))
       req <- GSUtils$GET(
@@ -203,7 +43,10 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
           dataStore <- switch(dsType,
               "Shapefile" = GSShapefileDataStore$new(xml = xml),
               "Directory of spatial files (shapefiles)" = GSShapefileDirectoryDataStore$new(xml = xml),
-              GSDataStore$new(xml = dsXML)
+              "GeoPackage" = GSGeoPackageDataStore$new(xml = xml),
+              "PostGIS" = GSPostGISDataStore$new(xml = xml),
+              "Oracle NG" = GSOracleNGDataStore$new(xml = xml),
+              GSAbstractDataStore$new(xml = dsXML)
           )
           return(dataStore)
         })
@@ -214,15 +57,18 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(dsList)
     },
     
-    #getDataStoreNames
-    #---------------------------------------------------------------------------
+    #'@description Get the list of available dataStore names.
+    #'@param ws workspace name
+    #'@return a vector of class \code{character}
     getDataStoreNames = function(ws){
       dsList <- sapply(self$getDataStores(ws), function(x){x$name})
       return(dsList)
     },
     
-    #getDataStore
-    #---------------------------------------------------------------------------
+    #'@description Get an object of class \code{\link{GSAbstractDataStore}} given a workspace and datastore names.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@return the datastore
     getDataStore = function(ws, ds){
       self$INFO(sprintf("Fetching datastore '%s' in workspace '%s'", ds, ws))
       req <- GSUtils$GET(
@@ -237,7 +83,10 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
         dataStore <- switch(dsType,
           "Shapefile" = GSShapefileDataStore$new(xml = dsXML),
           "Directory of spatial files (shapefiles)" = GSShapefileDirectoryDataStore$new(xml = dsXML),
-          GSDataStore$new(xml = dsXML)
+          "GeoPackage" = GSGeoPackageDataStore$new(xml = dsXML),
+          "PostGIS" = GSPostGISDataStore$new(xml = xml),
+          "Oracle NG" = GSOracleNGDataStore$new(xml = xml),
+          GSAbstractDataStore$new(xml = dsXML)
         )
         self$INFO("Successfully fetched datastore!")
       }else{
@@ -246,8 +95,10 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(dataStore)
     },
     
-    #createDataStore
-    #---------------------------------------------------------------------------
+    #'@description Creates a datastore given a workspace and an object of class \code{\link{GSAbstractDataStore}}.
+    #'@param ws workspace name
+    #'@param dataStore datastore object of class \link{GSAbstractDataStore}
+    #'@return \code{TRUE} if created, \code{FALSE} otherwise
     createDataStore = function(ws, dataStore){
       self$INFO(sprintf("Creating datastore '%s' in workspace '%s'", dataStore$name, ws))
       created <- FALSE
@@ -268,8 +119,11 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       }
     },
     
-    #updatDataStore
-    #---------------------------------------------------------------------------
+    
+    #'@description Updates a datastore given a workspace and an object of class \code{\link{GSAbstractDataStore}}.
+    #'@param ws workspace name
+    #'@param dataStore datastore object of class \link{GSAbstractDataStore}
+    #'@return \code{TRUE} if updated, \code{FALSE} otherwise
     updateDataStore = function(ws, dataStore){
       updated <- FALSE
       self$INFO(sprintf("Updating datastore '%s' in workspace '%s'", dataStore$name, ws))
@@ -290,8 +144,13 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(updated)
     },
     
-    #deleteDataStore
-    #---------------------------------------------------------------------------
+    #'@description Deletes a datastore given workspace and datastore names.
+    #'    By defaut, the option \code{recurse} is set to FALSE, ie datastore layers are not removed.
+    #'    To remove all datastore layers, set this option to TRUE.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param recurse recurse 
+    #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
     deleteDataStore = function(ws, ds, recurse = FALSE){
       self$INFO(sprintf("Deleting datastore '%s' in workspace '%s'", ds, ws))
       deleted <- FALSE
@@ -312,8 +171,11 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
     #DataStore featureType CRUD methods
     #===========================================================================
     
-    #getFeatureTypes
-    #---------------------------------------------------------------------------
+    #'@description Get the list of available feature types for given workspace and datastore.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param list list type value, among "configured", "available", "available_with_geom", "all"
+    #'@return an object of class \code{list} giving items of class \code{\link{GSFeatureType}}
     getFeatureTypes = function(ws, ds, list = "configured"){
       self$INFO(sprintf("Fetching featureTypes for datastore '%s' in workspace '%s'", ds, ws))
       supportedListValues <- c("configured", "available", "available_with_geom", "all")
@@ -342,15 +204,20 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(ftList)
     },
     
-    #getFeatureTypeNames
-    #---------------------------------------------------------------------------
+    #'@description Get the list of available feature type names for given workspace and datastore.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@return a vector of class\code{character}
     getFeatureTypeNames = function(ws, ds){
       ftList <- sapply(self$getFeatureTypes(ws, ds), function(x){x$name})
       return(ftList)
     },
     
-    #getFeatureType
-    #---------------------------------------------------------------------------
+    #'@description Get an object of class \code{\link{GSFeatureType}} given a workspace, datastore and feature type names.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param ft feature type name
+    #'@return an object of class \link{GSFeatureType}
     getFeatureType = function(ws, ds, ft){
       self$INFO(sprintf("Fetching featureType '%s' in datastore '%s' (workspace '%s')", ft, ds, ws))
       req <- GSUtils$GET(
@@ -369,8 +236,11 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(featureType)
     },
     
-    #createFeatureType
-    #---------------------------------------------------------------------------
+    #'@description Creates a new featureType given a workspace, datastore names and an object of class \code{\link{GSFeatureType}}
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param featureType feature type
+    #'@return \code{TRUE} if created, \code{FALSE} otherwise
     createFeatureType = function(ws, ds, featureType){
       self$INFO(sprintf("Creating featureType '%s' in datastore '%s' (workspace '%s')", featureType$name, ds, ws))
       created <- FALSE
@@ -392,8 +262,11 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(created)
     },
     
-    #updateFeatureType
-    #---------------------------------------------------------------------------
+    #'@description Updates a featureType given a workspace, datastore names and an object of class \code{\link{GSFeatureType}}
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param featureType feature type
+    #'@return \code{TRUE} if updated, \code{FALSE} otherwise
     updateFeatureType = function(ws, ds, featureType){
       self$INFO(sprintf("Updating featureType '%s' in datastore '%s' (workspace '%s')", featureType$name, ds, ws))
       updated <- FALSE
@@ -415,8 +288,14 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(updated)
     },
     
-    #deleteFeatureType
-    #---------------------------------------------------------------------------
+    #'@description Deletes a featureType given a workspace, datastore names, and an object of 
+    #'    class \code{\link{GSFeatureType}}. By defaut, the option \code{recurse} is 
+    #'    set to FALSE, ie datastore layers are not removed.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param ft feature type name
+    #'@param recurse recurse
+    #'@return \code{TRUE} if deleted, \code{FALSE} otherwise
     deleteFeatureType = function(ws, ds, ft, recurse = FALSE){
       self$INFO(sprintf("Deleting featureType '%s' in datastore '%s' (workspace '%s')", ft, ds, ws))
       deleted <- FALSE
@@ -434,268 +313,15 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(deleted)  
     },
     
-    #Layer CRUD methods
-    #===========================================================================
-
-    #getLayers
-    #---------------------------------------------------------------------------
-    getLayers = function(){
-      self$INFO("Fetching layers")
-      req <- GSUtils$GET(
-        self$getUrl(), private$user, 
-        private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        "/layers.xml", verbose = self$verbose.debug)
-      lyrList <- NULL
-      if(status_code(req) == 200){
-        lyrXML <- GSUtils$parseResponseXML(req)
-        lyrXMLList <- getNodeSet(lyrXML, "//layers/layer")
-        lyrList <- lapply(lyrXMLList, function(x){
-          xml <- xmlDoc(x)
-          return(GSLayer$new(xml = xml))
-        })
-        self$INFO(sprintf("Successfuly fetched %s layers!", length(lyrList)))
-      }else{
-        self$ERROR("Error while fetching layers")
-      }
-      return(lyrList)
-    },
-    
-    #getLayerNames
-    #---------------------------------------------------------------------------
-    getLayerNames = function(){
-      lyrList <- sapply(self$getLayers(), function(x){x$name})
-      return(lyrList)
-    },
-    
-    #getLayer
-    #---------------------------------------------------------------------------
-    getLayer = function(lyr){
-      self$INFO(sprintf("Fetching layer '%s'", lyr))
-      req <- GSUtils$GET(
-        self$getUrl(), private$user,
-        private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        sprintf("/layers/%s.xml", lyr),
-        verbose = self$verbose.debug)
-      layer <- NULL
-      if(status_code(req) == 200){
-        lyrXML <- GSUtils$parseResponseXML(req)
-        layer <- GSLayer$new(xml = lyrXML)
-        self$INFO("Successfuly fetched layer!")
-      }else{
-        self$ERROR("Error while fetching layer")
-      }
-      return(layer)
-    },
-    
-    #createLayer
-    #---------------------------------------------------------------------------
-    createLayer = function(layer){
-      self$INFO(sprintf("Creating layer '%s'", layer$name))
-      created <- FALSE
-      req <- GSUtils$PUT(
-        url = self$getUrl(), user = private$user,
-        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        path = sprintf("/layers/%s.xml", layer$name),
-        content = GSUtils$getPayloadXML(layer),
-        contentType = "application/xml",
-        verbose = self$verbose.debug
-      )
-      if(status_code(req) == 200){
-        self$INFO("Successfuly created layer!")
-        created = TRUE
-      }else{
-        self$ERROR("Error while creating layer")
-      }
-      return(created)
-    },
-    
-    #updateLayer
-    #---------------------------------------------------------------------------
-    updateLayer = function(layer){
-      self$INFO(sprintf("Updating layer '%s'", layer$name))
-      updated <- FALSE
-      req <- GSUtils$PUT(
-        url = self$getUrl(), user = private$user,
-        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        path = sprintf("/layers/%s.xml", layer$name),
-        content = GSUtils$getPayloadXML(layer),
-        contentType = "application/xml",
-        verbose = self$verbose.debug
-      )
-      if(status_code(req) == 200){
-        self$INFO("Successfuly updated layer!")
-        updated = TRUE
-      }else{
-        self$ERROR("Error while updating layer")
-      }
-      return(updated)
-    },
-    
-    #deleteLayer
-    #---------------------------------------------------------------------------
-    deleteLayer = function(lyr){
-      self$INFO(sprintf("Deleting layer '%s'", lyr))
-      deleted <- FALSE
-      path <- sprintf("/layers/%s.xml", lyr)
-      req <- GSUtils$DELETE(self$getUrl(), private$user,
-                            private$keyring_backend$get(service = private$keyring_service, username = private$user),
-                            path = path, verbose = self$verbose.debug)
-      if(status_code(req) == 200){
-        self$INFO("Successfuly deleted layer!")
-        deleted = TRUE
-      }else{
-        self$ERROR("Error while deleting layer")
-      }
-      return(deleted)
-    },
-    
-    #LayerGroup CRUD methods
-    #===========================================================================
-    
-    #getLayerGroups
-    #---------------------------------------------------------------------------
-    getLayerGroups = function(ws = NULL){
-      if(missing(ws)){
-        self$INFO("Fetching layer groups")
-      }else{
-        self$INFO(sprintf("Fetching layer groups for workspace '%s'", ws))
-      }
-      req <- GSUtils$GET(
-        self$getUrl(), private$user,
-        private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        ifelse(missing(ws),"/layergroups.xml", sprintf("/workspaces/%s/layergroups.xml", ws)), 
-        verbose = self$verbose.debug)
-      lyrList <- NULL
-      if(status_code(req) == 200){
-        lyrXML <- GSUtils$parseResponseXML(req)
-        lyrXMLList <- getNodeSet(lyrXML, "//layerGroups/layerGroup")
-        lyrList <- lapply(lyrXMLList, function(x){
-          xml <- xmlDoc(x)
-          return(GSLayerGroup$new(xml = xml))
-        })
-        self$INFO(sprintf("Successfuly fetched %s layer groups!", length(lyrList)))
-      }else{
-        self$ERROR("Error while fetching layer groups")
-      }
-      return(lyrList)
-    },
-    
-    #getLayerGroupNames
-    #---------------------------------------------------------------------------
-    getLayerGroupNames = function(ws = NULL){
-      lyrList <- sapply(self$getLayerGroups(ws), function(x){x$name})
-      return(lyrList)
-    },
-    
-    #getLayerGroup
-    #---------------------------------------------------------------------------
-    getLayerGroup = function(lyr, ws = NULL){
-      if(is.null(ws)){
-        self$INFO(sprintf("Fetching layer group '%s'", lyr))
-      }else{
-        self$INFO(sprintf("Fetching layer group '%s' in workspace '%s'", lyr, ws))
-      }
-      req <- GSUtils$GET(
-        self$getUrl(), private$user,
-        private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        ifelse(is.null(ws),
-               sprintf("/layergroups/%s.xml", lyr),
-               sprintf("/workspaces/%s/layergroups/%s.xml", ws, lyr)),
-        verbose = self$verbose.debug)
-      layer <- NULL
-      if(status_code(req) == 200){
-        lyrXML <- GSUtils$parseResponseXML(req)
-        layer <- GSLayerGroup$new(xml = lyrXML)
-        self$INFO("Successfuly fetched layer group!")
-      }else{
-        self$ERROR("Error while fetching layer group")
-      }
-      return(layer)
-    },
-    
-    #createLayerGroup
-    #---------------------------------------------------------------------------
-    createLayerGroup = function(layerGroup, ws = NULL){
-      if(is.null(ws)){
-        self$INFO(sprintf("Creating layer group '%s'", layerGroup$name))
-      }else{
-        self$INFO(sprintf("Creating layer group '%s' in workspace '%s'", layerGroup$name, ws))
-      }
-      created <- FALSE
-      req <- GSUtils$POST(
-        url = self$getUrl(), user = private$user,
-        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        path = ifelse(is.null(ws),"/layergroups.xml",
-                      sprintf("/workspaces/%s/layergroups.xml", ws)),
-        content = GSUtils$getPayloadXML(layerGroup),
-        contentType = "application/xml",
-        verbose = self$verbose.debug
-      )
-      if(status_code(req) == 201){
-        self$INFO("Successfuly created layer group!")
-        created = TRUE
-      }else{
-        self$ERROR("Error while creating layer group")
-      }
-      return(created)
-    },
-    
-    #updateLayerGroup
-    #---------------------------------------------------------------------------
-    updateLayerGroup = function(layerGroup, ws = NULL){
-      if(is.null(ws)){
-        self$INFO(sprintf("Updating layer '%s'", layerGroup$name))
-      }else{
-        self$INFO(sprintf("Updating layer '%s' in workspace '%s'", layerGroup$name, ws))
-      }
-      updated <- FALSE
-      req <- GSUtils$PUT(
-        url = self$getUrl(), user = private$user,
-        pwd = private$keyring_backend$get(service = private$keyring_service, username = private$user),
-        path = ifelse(is.null(ws),
-                      sprintf("/layergroups/%s.xml", layerGroup$name),
-                      sprintf("/workspaces/%s/layergroups/%s.xml", ws, layerGroup$name)),
-        content = GSUtils$getPayloadXML(layerGroup),
-        contentType = "application/xml",
-        verbose = self$verbose.debug
-      )
-      if(status_code(req) == 200){
-        self$INFO("Successfuly updated layer group!")
-        updated = TRUE
-      }else{
-        self$ERROR("Error while updating layer group")
-      }
-      return(updated)
-    },
-    
-    #deleteLayerGroup
-    #---------------------------------------------------------------------------
-    deleteLayerGroup = function(lyr, ws = NULL){
-      if(is.null(ws)){
-        self$INFO(sprintf("Deleting layer group '%s'", lyr))
-      }else{
-        self$INFO(sprintf("Deleting layer group '%s' in workspace '%s'", lyr, ws))
-      }
-      deleted <- FALSE
-      path <- ifelse(is.null(ws),
-                     sprintf("/layergroups/%s.xml", lyr),
-                     sprintf("/workspaces/%s/layergroups/%s.xml", ws, lyr))
-      req <- GSUtils$DELETE(self$getUrl(), private$user, 
-                            private$keyring_backend$get(service = private$keyring_service, username = private$user),
-                            path = path, verbose = self$verbose.debug)
-      if(status_code(req) == 200){
-        self$INFO("Successfuly deleted layer group!")
-        deleted = TRUE
-      }else{
-        self$ERROR("Error while deleting layer group")
-      }
-      return(deleted)
-    },
-    
-    #Layer publication methods
+    #Featuretype Layer publication methods
     #===========================================================================    
-    #publishLayer
-    #---------------------------------------------------------------------------
+    #'@description Publish a feature type/layer pair given a workspace and datastore. The name 'layer' here 
+    #'encompasses both \link{GSFeatureType} and \link{GSLayer} resources.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param featureType object of class \link{GSFeatureType}
+    #'@param layer object of class \link{GSLayer}
+    #'@return \code{TRUE} if published, \code{FALSE} otherwise
     publishLayer = function(ws, ds, featureType, layer){
       self$INFO(sprintf("Publishing layer '%s'", layer$name))
       published <- FALSE
@@ -719,8 +345,12 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       return(published)
     },
     
-    #unpublishLayer
-    #---------------------------------------------------------------------------
+    #'@description Unpublish a feature type/layer pair given a workspace and datastore. The name 'layer' here 
+    #'encompasses both \link{GSFeatureType} and \link{GSLayer} resources.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param lyr layer name
+    #'@return \code{TRUE} if published, \code{FALSE} otherwise
     unpublishLayer = function(ws, ds, lyr){
       self$INFO(sprintf("Unpublishing layer '%s'", lyr))
       unpublished <- FALSE
@@ -741,8 +371,22 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
     
     #Upload methods
     #===========================================================================
-    #uploadData
-    #---------------------------------------------------------------------------
+    #'@description Uploads features data. The \code{extension} corresponds to the format/type of features to be uploaded among "shp", "spatialite", "h2", "gpkg". 
+    #'    The \code{endpoint} takes a value among \code{"file"} (default), \code{"url"} or \code{"external"}. The \code{filename} is the name 
+    #'    of the coverage file to upload and set for the newly created datastore. The \code{configure} parameter can take a value among values 
+    #'    \code{"none"} (indicates to configure only the datastore but no layer configuration) or \code{"first"} (configure 
+    #'    both datastore and layer). The \code{update} defines the strategy for the upload: \code{"append"} (default value) for 
+    #'    the first upload, \code{"overwrite"} in case the file should be overwriten.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param endpoint endpoint
+    #'@param extension extension
+    #'@param configure configure strategy among values: "first" or "none"
+    #'@param update update strategy, among values: "append", "overwrite"
+    #'@param filename file name of the resource to upload
+    #'@param charset charset
+    #'@param contentType content type
+    #'@return \code{TRUE} if uploaded, \code{FALSE} otherwise
     uploadData = function(ws, ds, endpoint = "file", extension,
                           configure = "first", update = "append", filename,
                           charset, contentType){
@@ -792,14 +436,28 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       if(!uploaded){
         self$ERROR("Error while uploading data")
         self$ERROR(http_status(req)$message)
+        self$ERROR("Response headers -->")
+        print(headers(req))
+        self$ERROR("Response content -->")
+        print(as(content(req), "character"))
       }
       return(uploaded)
     },
     
-    #uploadShapefile
-    #NOTES:
-    #see #32 issue when contentType = "application/zip" (?)
-    #---------------------------------------------------------------------------
+    #'@description Uploads zipped shapefile.
+    #'    The \code{endpoint} takes a value among \code{"file"} (default), \code{"url"} or \code{"external"}. The \code{filename} is the name 
+    #'    of the coverage file to upload and set for the newly created datastore. The \code{configure} parameter can take a value among values 
+    #'    \code{"none"} (indicates to configure only the datastore but no layer configuration) or \code{"first"} (configure 
+    #'    both datastore and layer). The \code{update} defines the strategy for the upload: \code{"append"} (default value) for 
+    #'    the first upload, \code{"overwrite"} in case the file should be overwriten.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param endpoint endpoint
+    #'@param configure configure strategy among values: "first" or "none"
+    #'@param update update strategy, among values: "append", "overwrite"
+    #'@param filename file name of the resource to upload
+    #'@param charset charset
+    #'@return \code{TRUE} if uploaded, \code{FALSE} otherwise
     uploadShapefile = function(ws, ds, endpoint = "file",
                                 configure = "first", update = "append",
                                filename, charset = "UTF-8"){
@@ -810,8 +468,20 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       )
     },
     
-    #uploadProperties (to test)
-    #---------------------------------------------------------------------------
+    #'@description Uploads properties.
+    #'    The \code{endpoint} takes a value among \code{"file"} (default), \code{"url"} or \code{"external"}. The \code{filename} is the name 
+    #'    of the coverage file to upload and set for the newly created datastore. The \code{configure} parameter can take a value among values 
+    #'    \code{"none"} (indicates to configure only the datastore but no layer configuration) or \code{"first"} (configure 
+    #'    both datastore and layer). The \code{update} defines the strategy for the upload: \code{"append"} (default value) for 
+    #'    the first upload, \code{"overwrite"} in case the file should be overwriten.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param endpoint endpoint
+    #'@param configure configure strategy among values: "first" or "none"
+    #'@param update update strategy, among values: "append", "overwrite"
+    #'@param filename file name of the resource to upload
+    #'@param charset charset
+    #'@return \code{TRUE} if uploaded, \code{FALSE} otherwise
     uploadProperties = function(ws, ds, endpoint = "file",
                                configure = "first", update = "append",
                                filename, charset = "UTF-8"){
@@ -822,8 +492,20 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       )
     },
     
-    #uploadH2 (to test)
-    #---------------------------------------------------------------------------
+    #'@description Uploads H2 database.
+    #'    The \code{endpoint} takes a value among \code{"file"} (default), \code{"url"} or \code{"external"}. The \code{filename} is the name 
+    #'    of the coverage file to upload and set for the newly created datastore. The \code{configure} parameter can take a value among values 
+    #'    \code{"none"} (indicates to configure only the datastore but no layer configuration) or \code{"first"} (configure 
+    #'    both datastore and layer). The \code{update} defines the strategy for the upload: \code{"append"} (default value) for 
+    #'    the first upload, \code{"overwrite"} in case the file should be overwriten.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param endpoint endpoint
+    #'@param configure configure strategy among values: "first" or "none"
+    #'@param update update strategy, among values: "append", "overwrite"
+    #'@param filename file name of the resource to upload
+    #'@param charset charset
+    #'@return \code{TRUE} if uploaded, \code{FALSE} otherwise
     uploadH2 = function(ws, ds, endpoint = "file",
                         configure = "first", update = "append",
                         filename, charset = "UTF-8"){
@@ -834,8 +516,20 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       )
     },
     
-    #uploadSpatialite (to test)
-    #---------------------------------------------------------------------------
+    #'@description Uploads spatialite file.
+    #'    The \code{endpoint} takes a value among \code{"file"} (default), \code{"url"} or \code{"external"}. The \code{filename} is the name 
+    #'    of the coverage file to upload and set for the newly created datastore. The \code{configure} parameter can take a value among values 
+    #'    \code{"none"} (indicates to configure only the datastore but no layer configuration) or \code{"first"} (configure 
+    #'    both datastore and layer). The \code{update} defines the strategy for the upload: \code{"append"} (default value) for 
+    #'    the first upload, \code{"overwrite"} in case the file should be overwriten.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param endpoint endpoint
+    #'@param configure configure strategy among values: "first" or "none"
+    #'@param update update strategy, among values: "append", "overwrite"
+    #'@param filename file name of the resource to upload
+    #'@param charset charset
+    #'@return \code{TRUE} if uploaded, \code{FALSE} otherwise
     uploadSpatialite = function(ws, ds, endpoint = "file",
                         configure = "first", update = "append",
                         filename, charset = "UTF-8"){
@@ -846,8 +540,20 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       )
     },
     
-    #uploadAppschema (to test)
-    #---------------------------------------------------------------------------
+    #'@description Uploads App schema.
+    #'    The \code{endpoint} takes a value among \code{"file"} (default), \code{"url"} or \code{"external"}. The \code{filename} is the name 
+    #'    of the coverage file to upload and set for the newly created datastore. The \code{configure} parameter can take a value among values 
+    #'    \code{"none"} (indicates to configure only the datastore but no layer configuration) or \code{"first"} (configure 
+    #'    both datastore and layer). The \code{update} defines the strategy for the upload: \code{"append"} (default value) for 
+    #'    the first upload, \code{"overwrite"} in case the file should be overwriten.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param endpoint endpoint
+    #'@param configure configure strategy among values: "first" or "none"
+    #'@param update update strategy, among values: "append", "overwrite"
+    #'@param filename file name of the resource to upload
+    #'@param charset charset
+    #'@return \code{TRUE} if uploaded, \code{FALSE} otherwise
     uploadAppschema = function(ws, ds, endpoint = "file",
                                 configure = "first", update = "append",
                                 filename, charset = "UTF-8"){
@@ -858,8 +564,20 @@ GSDataStoreManager <- R6Class("GSDataStoreManager",
       )
     },
     
-    #uploadGeoPackage
-    #---------------------------------------------------------------------------
+    #'@description Uploads GeoPackage.
+    #'    The \code{endpoint} takes a value among \code{"file"} (default), \code{"url"} or \code{"external"}. The \code{filename} is the name 
+    #'    of the coverage file to upload and set for the newly created datastore. The \code{configure} parameter can take a value among values 
+    #'    \code{"none"} (indicates to configure only the datastore but no layer configuration) or \code{"first"} (configure 
+    #'    both datastore and layer). The \code{update} defines the strategy for the upload: \code{"append"} (default value) for 
+    #'    the first upload, \code{"overwrite"} in case the file should be overwriten.
+    #'@param ws workspace name
+    #'@param ds datastore name
+    #'@param endpoint endpoint
+    #'@param configure configure strategy among values: "first" or "none"
+    #'@param update update strategy, among values: "append", "overwrite"
+    #'@param filename file name of the resource to upload
+    #'@param charset charset
+    #'@return \code{TRUE} if uploaded, \code{FALSE} otherwise
     uploadGeoPackage = function(ws, ds, endpoint = "file",
                                configure = "first", update = "append",
                                filename, charset = "UTF-8"){
